"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ContextResolver = void 0;
const http_client_1 = require("./http-client");
class ContextResolver {
    constructor(app) {
        this.app = app;
    }
    async fromSource(req) {
        const webHookBody = JSON.parse(req.body);
        const shop = await this.app.repository.getShopById(webHookBody.source.shopId);
        if (shop === null) {
            throw new Error(`Cannot find shop by id ${webHookBody.source.shopId}`);
        }
        await this.app.signer.verifyPostRequest(req, shop.shopSecret);
        return new Context(shop, webHookBody, new http_client_1.HttpClient(shop));
    }
    async fromModule(req) {
        const shop = await this.app.repository.getShopById(req.query.get('shop-id'));
        if (shop === null) {
            throw new Error(`Cannot find shop by id ${req.query.get('shop-id')}`);
        }
        await this.app.signer.verifyGetRequest(req, shop.shopSecret);
        return new Context(shop, req.query, new http_client_1.HttpClient(shop));
    }
}
exports.ContextResolver = ContextResolver;
class Context {
    constructor(shop, payload, httpClient) {
        this.shop = shop;
        this.payload = payload;
        this.httpClient = httpClient;
    }
}
