"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Registration = void 0;
const server_1 = require("../server");
const shop_1 = require("../shop");
const util_1 = require("../util");
class Registration {
    constructor(app) {
        this.app = app;
    }
    async authorize(req) {
        if (!req.query.has('shop-url') ||
            !req.headers.has('shopware-app-signature') ||
            !req.query.has('shop-id') ||
            !req.query.has('timestamp')) {
            throw new Error('Invalid Request');
        }
        const v = await this.app.signer.verify(req.headers.get('shopware-app-signature'), `shop-id=${req.query.get('shop-id')}&shop-url=${req.query.get('shop-url')}&timestamp=${req.query.get('timestamp')}`, this.app.cfg.appSecret);
        if (!v) {
            throw new Error('Cannot validate app signature');
        }
        const shop = new shop_1.Shop(req.query.get('shop-id'), req.query.get('shop-url'), util_1.randomString());
        await this.app.repository.createShop(shop);
        return new server_1.JsonResponse(server_1.HTTP_OK, {
            proof: await this.app.signer.sign(shop.id + shop.shopUrl + this.app.cfg.appName, this.app.cfg.appSecret),
            secret: shop.shopSecret,
            confirmation_url: this.app.cfg.authorizeCallbackUrl
        });
    }
    async authorizeCallback(req, sucessHandler) {
        const body = JSON.parse(req.body);
        if (typeof body.shopId !== 'string' || typeof body.apiKey !== 'string' || typeof body.secretKey !== 'string' || !req.headers.has('shopware-shop-signature')) {
            throw new Error('Invalid Request');
        }
        const shop = await this.app.repository.getShopById(body.shopId);
        if (shop === null) {
            throw new Error(`Cannot find shop for this id: ${body.shopId}`);
        }
        const v = await this.app.signer.verify(req.headers.get('shopware-shop-signature'), req.body, shop.shopSecret);
        if (!v) {
            // Shop has failed the verify. Delete it from our DB
            await this.app.repository.deleteShop(shop);
            throw new Error('Cannot validate app signature');
        }
        shop.clientId = body.apiKey;
        shop.clientSecret = body.secretKey;
        if (sucessHandler) {
            await sucessHandler(shop);
        }
        await this.app.repository.updateShop(shop);
        return new server_1.JsonResponse(server_1.HTTP_OK, { success: true });
    }
}
exports.Registration = Registration;
