"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WebCryptoHmacSigner = exports.HmacSigner = void 0;
class HmacSigner {
    async signResponse(response, secret) {
        response.headers.set('shopware-app-signature', await this.sign(response.body, secret));
    }
    async verifyPostRequest(request, secret) {
        return await this.verify(request.headers.get('shopware-shop-signature'), request.body, secret);
    }
    async verifyGetRequest(request, secret) {
        // @ts-ignore
        const params = new URLSearchParams(request.query);
        const signature = params.get('shopware-shop-signature');
        params.delete('shopware-shop-signature');
        return await this.verify(signature, params.toString(), secret);
    }
}
exports.HmacSigner = HmacSigner;
class WebCryptoHmacSigner extends HmacSigner {
    constructor() {
        super();
        this.encoder = new TextEncoder();
        this.keyCache = new Map();
    }
    async getKeyForSecret(secret) {
        if (this.keyCache.has(secret)) {
            return this.keyCache.get(secret);
        }
        const secretKeyData = this.encoder.encode(secret);
        const key = await crypto.subtle.importKey('raw', secretKeyData, { name: 'HMAC', hash: 'SHA-256' }, false, ['sign', 'verify']);
        this.keyCache.set(secret, key);
        return key;
    }
    async sign(message, secret) {
        const key = await this.getKeyForSecret(secret);
        const mac = await crypto.subtle.sign('HMAC', key, this.encoder.encode(message));
        return this.buf2hex(mac);
    }
    async verify(signature, data, secret) {
        const signed = await this.sign(data, secret);
        return signature === signed;
    }
    buf2hex(buf) {
        return Array.prototype.map.call(new Uint8Array(buf), x => (('00' + x.toString(16)).slice(-2))).join('');
    }
}
exports.WebCryptoHmacSigner = WebCryptoHmacSigner;
