"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.convertResponse = exports.convertRequest = exports.CloudflareShopRepository = void 0;
const shop_1 = require("../../shop");
class CloudflareShopRepository {
    constructor(storage) {
        this.storage = storage;
    }
    async createShop(shop) {
        await this.storage.put(shop.id, JSON.stringify(shop));
    }
    async deleteShop(shop) {
        await this.storage.delete(shop.id);
    }
    async getShopById(id) {
        const kvObj = await this.storage.get(id);
        if (kvObj === null) {
            return null;
        }
        const obj = JSON.parse(kvObj);
        return new shop_1.Shop(obj.id || '', obj.shopUrl || '', obj.shopSecret || '', obj.clientId || '', obj.clientSecret || '', obj.customFields || {});
    }
    async updateShop(shop) {
        return await this.createShop(shop);
    }
}
exports.CloudflareShopRepository = CloudflareShopRepository;
async function convertRequest(request) {
    const { searchParams } = new URL(request.url);
    const queries = new Map();
    const headers = new Map();
    searchParams.forEach((val, key) => {
        queries.set(key, val);
    });
    request.headers.forEach((val, key) => {
        headers.set(key, val);
    });
    let body = '';
    try {
        body = await request.text();
    }
    catch (e) { }
    return {
        query: queries,
        method: request.method,
        headers: headers,
        body: body
    };
}
exports.convertRequest = convertRequest;
async function convertResponse(response) {
    const headers = {};
    response.headers.forEach((val, key) => {
        headers[key] = val;
    });
    return new Response(response.body, {
        status: response.statusCode,
        headers: headers
    });
}
exports.convertResponse = convertResponse;
